"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LcmGenerationStyle(str, Enum):
    r"""The style to generate LCM images with."""

    ANIME = "ANIME"
    CINEMATIC = "CINEMATIC"
    DIGITAL_ART = "DIGITAL_ART"
    DYNAMIC = "DYNAMIC"
    ENVIRONMENT = "ENVIRONMENT"
    FANTASY_ART = "FANTASY_ART"
    ILLUSTRATION = "ILLUSTRATION"
    PHOTOGRAPHY = "PHOTOGRAPHY"
    RENDER_3_D = "RENDER_3D"
    RAYTRACED = "RAYTRACED"
    SKETCH_BW = "SKETCH_BW"
    SKETCH_COLOR = "SKETCH_COLOR"
    VIBRANT = "VIBRANT"
    NONE = "NONE"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from leonardo_ai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UploadDatasetImageRequestBodyTypedDict(TypedDict):
    r"""Query parameters provided in the request body as a JSON object"""

    extension: str
    r"""Has to be png, jpg, jpeg, or webp."""


class UploadDatasetImageRequestBody(BaseModel):
    r"""Query parameters provided in the request body as a JSON object"""

    extension: str
    r"""Has to be png, jpg, jpeg, or webp."""


class UploadDatasetImageRequestTypedDict(TypedDict):
    request_body: UploadDatasetImageRequestBodyTypedDict
    r"""Query parameters provided in the request body as a JSON object"""
    dataset_id: str
    r"""_\"datasetId\" is required"""


class UploadDatasetImageRequest(BaseModel):
    request_body: Annotated[
        UploadDatasetImageRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Query parameters provided in the request body as a JSON object"""

    dataset_id: Annotated[
        str,
        pydantic.Field(alias="datasetId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""_\"datasetId\" is required"""


class DatasetUploadOutputTypedDict(TypedDict):
    fields: NotRequired[Nullable[str]]
    id: NotRequired[Nullable[str]]
    key: NotRequired[Nullable[str]]
    url: NotRequired[Nullable[str]]


class DatasetUploadOutput(BaseModel):
    fields: OptionalNullable[str] = UNSET

    id: OptionalNullable[str] = UNSET

    key: OptionalNullable[str] = UNSET

    url: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["fields", "id", "key", "url"]
        nullable_fields = ["fields", "id", "key", "url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UploadDatasetImageResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /datasets/{datasetId}/upload"""

    upload_dataset_image: NotRequired[Nullable[DatasetUploadOutputTypedDict]]


class UploadDatasetImageResponseBody(BaseModel):
    r"""Responses for POST /datasets/{datasetId}/upload"""

    upload_dataset_image: Annotated[
        OptionalNullable[DatasetUploadOutput],
        pydantic.Field(alias="uploadDatasetImage"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["uploadDatasetImage"]
        nullable_fields = ["uploadDatasetImage"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UploadDatasetImageResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[UploadDatasetImageResponseBodyTypedDict]
    r"""Responses for POST /datasets/{datasetId}/upload"""


class UploadDatasetImageResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[UploadDatasetImageResponseBody] = None
    r"""Responses for POST /datasets/{datasetId}/upload"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from leonardo_ai_sdk import utils
from leonardo_ai_sdk._hooks import HookContext
from leonardo_ai_sdk.models import errors, operations
from leonardo_ai_sdk.types import BaseModel, OptionalNullable, UNSET
from typing import Mapping, Optional, Union, cast


class Variation(BaseSDK):
    def create_universal_upscaler_job(
        self,
        *,
        request: Union[
            operations.CreateUniversalUpscalerJobRequestBody,
            operations.CreateUniversalUpscalerJobRequestBodyTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateUniversalUpscalerJobResponse:
        r"""Create using Universal Upscaler

        This endpoint will create a high resolution image using Universal Upscaler

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, operations.CreateUniversalUpscalerJobRequestBody
            )
        request = cast(operations.CreateUniversalUpscalerJobRequestBody, request)

        req = self._build_request(
            method="POST",
            path="/variations/universal-upscaler",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "json",
                operations.CreateUniversalUpscalerJobRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="CreateUniversalUpscalerJob",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateUniversalUpscalerJobResponse(
                object=utils.unmarshal_json(
                    http_res.text,
                    Optional[operations.CreateUniversalUpscalerJobResponseBody],
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def create_universal_upscaler_job_async(
        self,
        *,
        request: Union[
            operations.CreateUniversalUpscalerJobRequestBody,
            operations.CreateUniversalUpscalerJobRequestBodyTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateUniversalUpscalerJobResponse:
        r"""Create using Universal Upscaler

        This endpoint will create a high resolution image using Universal Upscaler

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, operations.CreateUniversalUpscalerJobRequestBody
            )
        request = cast(operations.CreateUniversalUpscalerJobRequestBody, request)

        req = self._build_request_async(
            method="POST",
            path="/variations/universal-upscaler",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "json",
                operations.CreateUniversalUpscalerJobRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="CreateUniversalUpscalerJob",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateUniversalUpscalerJobResponse(
                object=utils.unmarshal_json(
                    http_res.text,
                    Optional[operations.CreateUniversalUpscalerJobResponseBody],
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def create_variation_no_bg(
        self,
        *,
        request: Union[
            operations.CreateVariationNoBGRequestBody,
            operations.CreateVariationNoBGRequestBodyTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateVariationNoBGResponse:
        r"""Create no background

        This endpoint will create a no background variation of the provided image ID

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, operations.CreateVariationNoBGRequestBody
            )
        request = cast(operations.CreateVariationNoBGRequestBody, request)

        req = self._build_request(
            method="POST",
            path="/variations/nobg",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", operations.CreateVariationNoBGRequestBody
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="createVariationNoBG",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateVariationNoBGResponse(
                object=utils.unmarshal_json(
                    http_res.text, Optional[operations.CreateVariationNoBGResponseBody]
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def create_variation_no_bg_async(
        self,
        *,
        request: Union[
            operations.CreateVariationNoBGRequestBody,
            operations.CreateVariationNoBGRequestBodyTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateVariationNoBGResponse:
        r"""Create no background

        This endpoint will create a no background variation of the provided image ID

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, operations.CreateVariationNoBGRequestBody
            )
        request = cast(operations.CreateVariationNoBGRequestBody, request)

        req = self._build_request_async(
            method="POST",
            path="/variations/nobg",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", operations.CreateVariationNoBGRequestBody
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="createVariationNoBG",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateVariationNoBGResponse(
                object=utils.unmarshal_json(
                    http_res.text, Optional[operations.CreateVariationNoBGResponseBody]
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def create_variation_unzoom(
        self,
        *,
        request: Optional[
            Union[
                operations.CreateVariationUnzoomRequestBody,
                operations.CreateVariationUnzoomRequestBodyTypedDict,
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateVariationUnzoomResponse:
        r"""Create unzoom

        This endpoint will create an unzoom variation for the provided image ID

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, Optional[operations.CreateVariationUnzoomRequestBody]
            )
        request = cast(Optional[operations.CreateVariationUnzoomRequestBody], request)

        req = self._build_request(
            method="POST",
            path="/variations/unzoom",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                True,
                "json",
                Optional[operations.CreateVariationUnzoomRequestBody],
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="createVariationUnzoom",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateVariationUnzoomResponse(
                object=utils.unmarshal_json(
                    http_res.text,
                    Optional[operations.CreateVariationUnzoomResponseBody],
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def create_variation_unzoom_async(
        self,
        *,
        request: Optional[
            Union[
                operations.CreateVariationUnzoomRequestBody,
                operations.CreateVariationUnzoomRequestBodyTypedDict,
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateVariationUnzoomResponse:
        r"""Create unzoom

        This endpoint will create an unzoom variation for the provided image ID

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, Optional[operations.CreateVariationUnzoomRequestBody]
            )
        request = cast(Optional[operations.CreateVariationUnzoomRequestBody], request)

        req = self._build_request_async(
            method="POST",
            path="/variations/unzoom",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                True,
                "json",
                Optional[operations.CreateVariationUnzoomRequestBody],
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="createVariationUnzoom",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateVariationUnzoomResponse(
                object=utils.unmarshal_json(
                    http_res.text,
                    Optional[operations.CreateVariationUnzoomResponseBody],
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def create_variation_upscale(
        self,
        *,
        request: Optional[
            Union[
                operations.CreateVariationUpscaleRequestBody,
                operations.CreateVariationUpscaleRequestBodyTypedDict,
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateVariationUpscaleResponse:
        r"""Create upscale

        This endpoint will create an upscale for the provided image ID

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, Optional[operations.CreateVariationUpscaleRequestBody]
            )
        request = cast(Optional[operations.CreateVariationUpscaleRequestBody], request)

        req = self._build_request(
            method="POST",
            path="/variations/upscale",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                True,
                "json",
                Optional[operations.CreateVariationUpscaleRequestBody],
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="createVariationUpscale",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateVariationUpscaleResponse(
                object=utils.unmarshal_json(
                    http_res.text,
                    Optional[operations.CreateVariationUpscaleResponseBody],
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def create_variation_upscale_async(
        self,
        *,
        request: Optional[
            Union[
                operations.CreateVariationUpscaleRequestBody,
                operations.CreateVariationUpscaleRequestBodyTypedDict,
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateVariationUpscaleResponse:
        r"""Create upscale

        This endpoint will create an upscale for the provided image ID

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, Optional[operations.CreateVariationUpscaleRequestBody]
            )
        request = cast(Optional[operations.CreateVariationUpscaleRequestBody], request)

        req = self._build_request_async(
            method="POST",
            path="/variations/upscale",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                True,
                "json",
                Optional[operations.CreateVariationUpscaleRequestBody],
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="createVariationUpscale",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateVariationUpscaleResponse(
                object=utils.unmarshal_json(
                    http_res.text,
                    Optional[operations.CreateVariationUpscaleResponseBody],
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get_variation_by_id(
        self,
        *,
        id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.GetVariationByIDResponse:
        r"""Get variation by ID

        This endpoint will get the variation by ID

        :param id: \"id\" is required
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = operations.GetVariationByIDRequest(
            id=id,
        )

        req = self._build_request(
            method="GET",
            path="/variations/{id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="getVariationById",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.GetVariationByIDResponse(
                object=utils.unmarshal_json(
                    http_res.text, Optional[operations.GetVariationByIDResponseBody]
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_variation_by_id_async(
        self,
        *,
        id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.GetVariationByIDResponse:
        r"""Get variation by ID

        This endpoint will get the variation by ID

        :param id: \"id\" is required
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = operations.GetVariationByIDRequest(
            id=id,
        )

        req = self._build_request_async(
            method="GET",
            path="/variations/{id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="getVariationById",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.GetVariationByIDResponse(
                object=utils.unmarshal_json(
                    http_res.text, Optional[operations.GetVariationByIDResponseBody]
                ),
                status_code=http_res.status_code,
                content_type=http_res.headers.get("Content-Type") or "",
                raw_response=http_res,
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomModelType(str, Enum):
    r"""The category the most accurately reflects the model."""

    GENERAL = "GENERAL"
    BUILDINGS = "BUILDINGS"
    CHARACTERS = "CHARACTERS"
    ENVIRONMENTS = "ENVIRONMENTS"
    FASHION = "FASHION"
    ILLUSTRATIONS = "ILLUSTRATIONS"
    GAME_ITEMS = "GAME_ITEMS"
    GRAPHICAL_ELEMENTS = "GRAPHICAL_ELEMENTS"
    PHOTOGRAPHY = "PHOTOGRAPHY"
    PIXEL_ART = "PIXEL_ART"
    PRODUCT_DESIGN = "PRODUCT_DESIGN"
    TEXTURES = "TEXTURES"
    UI_ELEMENTS = "UI_ELEMENTS"
    VECTOR = "VECTOR"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SdGenerationStyle(str, Enum):
    r"""The style to generate images with. When photoReal is enabled, refer to the Guide section for a full list. When alchemy is disabled, use LEONARDO or NONE. When alchemy is enabled, use ANIME, CREATIVE, DYNAMIC, ENVIRONMENT, GENERAL, ILLUSTRATION, PHOTOGRAPHY, RAYTRACED, RENDER_3D, SKETCH_BW, SKETCH_COLOR, or NONE."""

    ANIME = "ANIME"
    BOKEH = "BOKEH"
    CINEMATIC = "CINEMATIC"
    CINEMATIC_CLOSEUP = "CINEMATIC_CLOSEUP"
    CREATIVE = "CREATIVE"
    DYNAMIC = "DYNAMIC"
    ENVIRONMENT = "ENVIRONMENT"
    FASHION = "FASHION"
    FILM = "FILM"
    FOOD = "FOOD"
    GENERAL = "GENERAL"
    HDR = "HDR"
    ILLUSTRATION = "ILLUSTRATION"
    LEONARDO = "LEONARDO"
    LONG_EXPOSURE = "LONG_EXPOSURE"
    MACRO = "MACRO"
    MINIMALISTIC = "MINIMALISTIC"
    MONOCHROME = "MONOCHROME"
    MOODY = "MOODY"
    NONE = "NONE"
    NEUTRAL = "NEUTRAL"
    PHOTOGRAPHY = "PHOTOGRAPHY"
    PORTRAIT = "PORTRAIT"
    RAYTRACED = "RAYTRACED"
    RENDER_3_D = "RENDER_3D"
    RETRO = "RETRO"
    SKETCH_BW = "SKETCH_BW"
    SKETCH_COLOR = "SKETCH_COLOR"
    STOCK_PHOTO = "STOCK_PHOTO"
    VIBRANT = "VIBRANT"
    UNPROCESSED = "UNPROCESSED"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ListPlatformModelsGeneratedImagesTypedDict(TypedDict):
    r"""columns and relationships of \"generated_images\" """

    id: NotRequired[Nullable[str]]
    url: NotRequired[str]


class ListPlatformModelsGeneratedImages(BaseModel):
    r"""columns and relationships of \"generated_images\" """

    id: OptionalNullable[str] = UNSET

    url: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "url"]
        nullable_fields = ["id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ListPlatformModelsCustomModelsTypedDict(TypedDict):
    r"""columns and relationships of \"custom_models\" """

    description: NotRequired[str]
    featured: NotRequired[bool]
    generated_image: NotRequired[Nullable[ListPlatformModelsGeneratedImagesTypedDict]]
    r"""columns and relationships of \"generated_images\" """
    id: NotRequired[Nullable[str]]
    name: NotRequired[str]
    nsfw: NotRequired[bool]


class ListPlatformModelsCustomModels(BaseModel):
    r"""columns and relationships of \"custom_models\" """

    description: Optional[str] = None

    featured: Optional[bool] = None

    generated_image: OptionalNullable[ListPlatformModelsGeneratedImages] = UNSET
    r"""columns and relationships of \"generated_images\" """

    id: OptionalNullable[str] = UNSET

    name: Optional[str] = None

    nsfw: Optional[bool] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "description",
            "featured",
            "generated_image",
            "id",
            "name",
            "nsfw",
        ]
        nullable_fields = ["generated_image", "id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ListPlatformModelsResponseBodyTypedDict(TypedDict):
    r"""Responses for GET /api/rest/v1/platformModels"""

    custom_models: NotRequired[List[ListPlatformModelsCustomModelsTypedDict]]


class ListPlatformModelsResponseBody(BaseModel):
    r"""Responses for GET /api/rest/v1/platformModels"""

    custom_models: Optional[List[ListPlatformModelsCustomModels]] = None


class ListPlatformModelsResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[ListPlatformModelsResponseBodyTypedDict]
    r"""Responses for GET /api/rest/v1/platformModels"""


class ListPlatformModelsResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[ListPlatformModelsResponseBody] = None
    r"""Responses for GET /api/rest/v1/platformModels"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PromptRandomPromptGenerationOutputTypedDict(TypedDict):
    api_credit_cost: NotRequired[int]
    r"""API Credits Cost for Random Prompt Generation. Available for Production API Users."""
    prompt: NotRequired[str]
    r"""The random prompt generated."""


class PromptRandomPromptGenerationOutput(BaseModel):
    api_credit_cost: Annotated[Optional[int], pydantic.Field(alias="apiCreditCost")] = 4
    r"""API Credits Cost for Random Prompt Generation. Available for Production API Users."""

    prompt: Optional[str] = "The random prompt generated."
    r"""The random prompt generated."""


class PromptRandomResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /prompt/random"""

    prompt_generation: NotRequired[PromptRandomPromptGenerationOutputTypedDict]


class PromptRandomResponseBody(BaseModel):
    r"""Responses for POST /prompt/random"""

    prompt_generation: Annotated[
        Optional[PromptRandomPromptGenerationOutput],
        pydantic.Field(alias="promptGeneration"),
    ] = None


class PromptRandomResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[PromptRandomResponseBodyTypedDict]
    r"""Responses for POST /prompt/random"""


class PromptRandomResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[PromptRandomResponseBody] = None
    r"""Responses for POST /prompt/random"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CanvasRequestType(str, Enum):
    r"""The type of request for the Canvas Editor."""

    INPAINT = "INPAINT"
    OUTPAINT = "OUTPAINT"
    SKETCH2_IMG = "SKETCH2IMG"
    IMG2_IMG = "IMG2IMG"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
import httpx
from leonardo_ai_sdk.models.shared import (
    custom_model_type as shared_custom_model_type,
    strength as shared_strength,
)
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateModelSdVersions(str, Enum):
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5."""

    V1_5 = "v1_5"
    V2 = "v2"


class CreateModelRequestBodyTypedDict(TypedDict):
    r"""Query parameters to be provided in the request body as a JSON object"""

    dataset_id: str
    r"""The ID of the dataset to train the model on."""
    instance_prompt: str
    r"""The instance prompt to use during training."""
    name: str
    r"""The name of the model."""
    description: NotRequired[Nullable[str]]
    r"""The description of the model."""
    model_type: NotRequired[shared_custom_model_type.CustomModelType]
    r"""The category the most accurately reflects the model."""
    nsfw: NotRequired[Nullable[bool]]
    r"""Whether or not the model is NSFW."""
    resolution: NotRequired[Nullable[int]]
    r"""The resolution for training. Must be 512 or 768."""
    sd_version: NotRequired[Nullable[CreateModelSdVersions]]
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5."""
    strength: NotRequired[shared_strength.Strength]
    r"""When training using the PIXEL_ART model type, this influences the training strength."""


class CreateModelRequestBody(BaseModel):
    r"""Query parameters to be provided in the request body as a JSON object"""

    dataset_id: Annotated[str, pydantic.Field(alias="datasetId")]
    r"""The ID of the dataset to train the model on."""

    instance_prompt: str
    r"""The instance prompt to use during training."""

    name: str
    r"""The name of the model."""

    description: OptionalNullable[str] = ""
    r"""The description of the model."""

    model_type: Annotated[
        Optional[shared_custom_model_type.CustomModelType],
        pydantic.Field(alias="modelType"),
    ] = shared_custom_model_type.CustomModelType.GENERAL
    r"""The category the most accurately reflects the model."""

    nsfw: OptionalNullable[bool] = False
    r"""Whether or not the model is NSFW."""

    resolution: OptionalNullable[int] = 512
    r"""The resolution for training. Must be 512 or 768."""

    sd_version: OptionalNullable[CreateModelSdVersions] = UNSET
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5."""

    strength: Optional[shared_strength.Strength] = shared_strength.Strength.MEDIUM
    r"""When training using the PIXEL_ART model type, this influences the training strength."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "description",
            "modelType",
            "nsfw",
            "resolution",
            "sd_version",
            "strength",
        ]
        nullable_fields = ["description", "nsfw", "resolution", "sd_version"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateModelSDTrainingOutputTypedDict(TypedDict):
    api_credit_cost: NotRequired[Nullable[int]]
    r"""API Credits Cost for Model Training. Available for Production API Users."""
    custom_model_id: NotRequired[str]


class CreateModelSDTrainingOutput(BaseModel):
    api_credit_cost: Annotated[
        OptionalNullable[int], pydantic.Field(alias="apiCreditCost")
    ] = UNSET
    r"""API Credits Cost for Model Training. Available for Production API Users."""

    custom_model_id: Annotated[Optional[str], pydantic.Field(alias="customModelId")] = (
        None
    )

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["apiCreditCost", "customModelId"]
        nullable_fields = ["apiCreditCost"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateModelResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /models"""

    sd_training_job: NotRequired[Nullable[CreateModelSDTrainingOutputTypedDict]]


class CreateModelResponseBody(BaseModel):
    r"""Responses for POST /models"""

    sd_training_job: Annotated[
        OptionalNullable[CreateModelSDTrainingOutput],
        pydantic.Field(alias="sdTrainingJob"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["sdTrainingJob"]
        nullable_fields = ["sdTrainingJob"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateModelResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[CreateModelResponseBodyTypedDict]
    r"""Responses for POST /models"""


class CreateModelResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[CreateModelResponseBody] = None
    r"""Responses for POST /models"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UniversalUpscalerUltraStyle(str, Enum):
    r"""The ultra style to upscale images using universal upscaler with. Can not be used with upscalerStyle."""

    ARTISTIC = "ARTISTIC"
    REALISTIC = "REALISTIC"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UniversalUpscalerStyle(str, Enum):
    r"""The style to upscale images using universal upscaler with. Can not be used with ultraUpscaleStyle."""

    GENERAL = "GENERAL"
    CINEMATIC = "CINEMATIC"
    TWO_D_ART_AND_ILLUSTRATION = "2D ART & ILLUSTRATION"
    CG_ART_AND_GAME_ASSETS = "CG ART & GAME ASSETS"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.models.shared import job_status as shared_job_status
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from leonardo_ai_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetCustomElementsByUserIDRequestTypedDict(TypedDict):
    user_id: str
    r"""The ID of the user to return."""


class GetCustomElementsByUserIDRequest(BaseModel):
    user_id: Annotated[
        str,
        pydantic.Field(alias="userId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The ID of the user to return."""


class GetCustomElementsByUserIDUserLorasTypedDict(TypedDict):
    r"""columns and relationships of \"user_loras\"."""

    base_model: NotRequired[str]
    created_at: NotRequired[str]
    description: NotRequired[str]
    focus: NotRequired[str]
    id: NotRequired[int]
    instance_prompt: NotRequired[Nullable[str]]
    learning_rate: NotRequired[float]
    name: NotRequired[str]
    resolution: NotRequired[int]
    status: NotRequired[shared_job_status.JobStatus]
    r"""The status of the current task."""
    train_text_encoder: NotRequired[bool]
    training_epoch: NotRequired[int]
    updated_at: NotRequired[str]


class GetCustomElementsByUserIDUserLoras(BaseModel):
    r"""columns and relationships of \"user_loras\"."""

    base_model: Annotated[Optional[str], pydantic.Field(alias="baseModel")] = None

    created_at: Annotated[Optional[str], pydantic.Field(alias="createdAt")] = None

    description: Optional[str] = None

    focus: Optional[str] = None

    id: Optional[int] = None

    instance_prompt: Annotated[
        OptionalNullable[str], pydantic.Field(alias="instancePrompt")
    ] = UNSET

    learning_rate: Annotated[Optional[float], pydantic.Field(alias="learningRate")] = (
        None
    )

    name: Optional[str] = None

    resolution: Optional[int] = None

    status: Optional[shared_job_status.JobStatus] = None
    r"""The status of the current task."""

    train_text_encoder: Annotated[
        Optional[bool], pydantic.Field(alias="trainTextEncoder")
    ] = None

    training_epoch: Annotated[Optional[int], pydantic.Field(alias="trainingEpoch")] = (
        None
    )

    updated_at: Annotated[Optional[str], pydantic.Field(alias="updatedAt")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "baseModel",
            "createdAt",
            "description",
            "focus",
            "id",
            "instancePrompt",
            "learningRate",
            "name",
            "resolution",
            "status",
            "trainTextEncoder",
            "trainingEpoch",
            "updatedAt",
        ]
        nullable_fields = ["instancePrompt"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetCustomElementsByUserIDResponseBodyTypedDict(TypedDict):
    r"""Responses for GET /elements/user/{userId}."""

    user_loras: NotRequired[Nullable[List[GetCustomElementsByUserIDUserLorasTypedDict]]]


class GetCustomElementsByUserIDResponseBody(BaseModel):
    r"""Responses for GET /elements/user/{userId}."""

    user_loras: OptionalNullable[List[GetCustomElementsByUserIDUserLoras]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["user_loras"]
        nullable_fields = ["user_loras"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetCustomElementsByUserIDResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[GetCustomElementsByUserIDResponseBodyTypedDict]
    r"""Responses for GET /elements/user/{userId}."""


class GetCustomElementsByUserIDResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[GetCustomElementsByUserIDResponseBody] = None
    r"""Responses for GET /elements/user/{userId}."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UploadModelAssetRequestBodyTypedDict(TypedDict):
    r"""Query parameters can also be provided in the request body as a JSON object"""

    model_extension: NotRequired[str]
    name: NotRequired[Nullable[str]]


class UploadModelAssetRequestBody(BaseModel):
    r"""Query parameters can also be provided in the request body as a JSON object"""

    model_extension: Annotated[
        Optional[str], pydantic.Field(alias="modelExtension")
    ] = None

    name: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["modelExtension", "name"]
        nullable_fields = ["name"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ModelAssetUploadOutputTypedDict(TypedDict):
    model_fields_: NotRequired[Nullable[str]]
    model_id: NotRequired[Nullable[str]]
    model_key: NotRequired[Nullable[str]]
    model_url: NotRequired[Nullable[str]]


class ModelAssetUploadOutput(BaseModel):
    model_fields_: Annotated[
        OptionalNullable[str], pydantic.Field(alias="modelFields")
    ] = UNSET

    model_id: Annotated[OptionalNullable[str], pydantic.Field(alias="modelId")] = UNSET

    model_key: Annotated[OptionalNullable[str], pydantic.Field(alias="modelKey")] = (
        UNSET
    )

    model_url: Annotated[OptionalNullable[str], pydantic.Field(alias="modelUrl")] = (
        UNSET
    )

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["modelFields", "modelId", "modelKey", "modelUrl"]
        nullable_fields = ["modelFields", "modelId", "modelKey", "modelUrl"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UploadModelAssetResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /api/rest/v1/models-3d/upload"""

    upload_model_asset: NotRequired[Nullable[ModelAssetUploadOutputTypedDict]]


class UploadModelAssetResponseBody(BaseModel):
    r"""Responses for POST /api/rest/v1/models-3d/upload"""

    upload_model_asset: Annotated[
        OptionalNullable[ModelAssetUploadOutput],
        pydantic.Field(alias="uploadModelAsset"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["uploadModelAsset"]
        nullable_fields = ["uploadModelAsset"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UploadModelAssetResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[UploadModelAssetResponseBodyTypedDict]
    r"""Responses for POST /api/rest/v1/models-3d/upload"""


class UploadModelAssetResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[UploadModelAssetResponseBody] = None
    r"""Responses for POST /api/rest/v1/models-3d/upload"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SdVersions(str, Enum):
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""

    V1_5 = "v1_5"
    V2 = "v2"
    V3 = "v3"
    SDXL_0_8 = "SDXL_0_8"
    SDXL_0_9 = "SDXL_0_9"
    SDXL_1_0 = "SDXL_1_0"
    SDXL_LIGHTNING = "SDXL_LIGHTNING"
    PHOENIX = "PHOENIX"
    FLUX = "FLUX"
    FLUX_DEV = "FLUX_DEV"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.models.shared import (
    pricingcalculatorservices as shared_pricingcalculatorservices,
)
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PricingCalculatorObjectTypedDict(TypedDict):
    r"""Parameters for FANTASY_AVATAR_GENERATION service"""

    image_height: NotRequired[int]
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""
    image_width: NotRequired[int]
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""
    num_images: NotRequired[int]
    r"""The number of images to generate. Must be between 1 and 8. If either width or height is over 768, must be between 1 and 4."""


class PricingCalculatorObject(BaseModel):
    r"""Parameters for FANTASY_AVATAR_GENERATION service"""

    image_height: Annotated[Optional[int], pydantic.Field(alias="imageHeight")] = None
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""

    image_width: Annotated[Optional[int], pydantic.Field(alias="imageWidth")] = None
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""

    num_images: Annotated[Optional[int], pydantic.Field(alias="numImages")] = None
    r"""The number of images to generate. Must be between 1 and 8. If either width or height is over 768, must be between 1 and 4."""


class PricingCalculatorPricingCalculatorObjectTypedDict(TypedDict):
    r"""Parameters for IMAGE_GENERATION service"""

    alchemy_mode: NotRequired[bool]
    r"""Enable to use Alchemy."""
    controlnets_cost: NotRequired[Nullable[int]]
    r"""The total cost of controlnets input."""
    high_resolution: NotRequired[bool]
    r"""Enable to use high resolution."""
    image_height: NotRequired[int]
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""
    image_width: NotRequired[int]
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""
    inference_steps: NotRequired[int]
    r"""The Step Count to use for the generation. Must be between 10 and 60."""
    is_model_custom: NotRequired[Nullable[bool]]
    r"""Enable to use custom model."""
    is_phoenix: NotRequired[Nullable[bool]]
    r"""Enable to use Phoenix model."""
    is_sdxl: NotRequired[Nullable[bool]]
    r"""Enable to use SDXL model."""
    is_sdxl_lightning: NotRequired[Nullable[bool]]
    r"""Enable to use SDXL Lightning model."""
    lora_count: NotRequired[Nullable[int]]
    r"""The number of elements used for the generation."""
    num_images: NotRequired[int]
    r"""The number of images to generate. Must be between 1 and 8. If either width or height is over 768, must be between 1 and 4."""
    photo_real_mode: NotRequired[Nullable[bool]]
    r"""Enable to use PhotoReal. Requires enabling alchemy."""
    photo_real_strength: NotRequired[Nullable[float]]
    r"""Depth of field of photoReal. Must be 0.55 for low, 0.5 for medium, or 0.45 for high. Defaults to 0.55 if not specified."""
    photo_real_version: NotRequired[Nullable[str]]
    r"""The version of photoReal to use. Must be v1 or v2."""
    prompt_magic: NotRequired[Nullable[bool]]
    r"""Enable to use Prompt Magic."""
    prompt_magic_strength: NotRequired[Nullable[float]]
    r"""Strength of prompt magic. Must be a float between 0.1 and 1.0"""
    prompt_magic_version: NotRequired[Nullable[str]]
    r"""Prompt magic version v2 or v3, for use when promptMagic: true"""
    ultra: NotRequired[Nullable[bool]]
    r"""Enable to use Ultra mode."""


class PricingCalculatorPricingCalculatorObject(BaseModel):
    r"""Parameters for IMAGE_GENERATION service"""

    alchemy_mode: Annotated[Optional[bool], pydantic.Field(alias="alchemyMode")] = None
    r"""Enable to use Alchemy."""

    controlnets_cost: Annotated[
        OptionalNullable[int], pydantic.Field(alias="controlnetsCost")
    ] = UNSET
    r"""The total cost of controlnets input."""

    high_resolution: Annotated[
        Optional[bool], pydantic.Field(alias="highResolution")
    ] = None
    r"""Enable to use high resolution."""

    image_height: Annotated[Optional[int], pydantic.Field(alias="imageHeight")] = None
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""

    image_width: Annotated[Optional[int], pydantic.Field(alias="imageWidth")] = None
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""

    inference_steps: Annotated[
        Optional[int], pydantic.Field(alias="inferenceSteps")
    ] = None
    r"""The Step Count to use for the generation. Must be between 10 and 60."""

    is_model_custom: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="isModelCustom")
    ] = UNSET
    r"""Enable to use custom model."""

    is_phoenix: Annotated[OptionalNullable[bool], pydantic.Field(alias="isPhoenix")] = (
        UNSET
    )
    r"""Enable to use Phoenix model."""

    is_sdxl: Annotated[OptionalNullable[bool], pydantic.Field(alias="isSDXL")] = UNSET
    r"""Enable to use SDXL model."""

    is_sdxl_lightning: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="isSDXLLightning")
    ] = UNSET
    r"""Enable to use SDXL Lightning model."""

    lora_count: Annotated[OptionalNullable[int], pydantic.Field(alias="loraCount")] = (
        UNSET
    )
    r"""The number of elements used for the generation."""

    num_images: Annotated[Optional[int], pydantic.Field(alias="numImages")] = None
    r"""The number of images to generate. Must be between 1 and 8. If either width or height is over 768, must be between 1 and 4."""

    photo_real_mode: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="photoRealMode")
    ] = UNSET
    r"""Enable to use PhotoReal. Requires enabling alchemy."""

    photo_real_strength: Annotated[
        OptionalNullable[float], pydantic.Field(alias="photoRealStrength")
    ] = UNSET
    r"""Depth of field of photoReal. Must be 0.55 for low, 0.5 for medium, or 0.45 for high. Defaults to 0.55 if not specified."""

    photo_real_version: Annotated[
        OptionalNullable[str], pydantic.Field(alias="photoRealVersion")
    ] = UNSET
    r"""The version of photoReal to use. Must be v1 or v2."""

    prompt_magic: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="promptMagic")
    ] = UNSET
    r"""Enable to use Prompt Magic."""

    prompt_magic_strength: Annotated[
        OptionalNullable[float], pydantic.Field(alias="promptMagicStrength")
    ] = UNSET
    r"""Strength of prompt magic. Must be a float between 0.1 and 1.0"""

    prompt_magic_version: Annotated[
        OptionalNullable[str], pydantic.Field(alias="promptMagicVersion")
    ] = UNSET
    r"""Prompt magic version v2 or v3, for use when promptMagic: true"""

    ultra: OptionalNullable[bool] = UNSET
    r"""Enable to use Ultra mode."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "alchemyMode",
            "controlnetsCost",
            "highResolution",
            "imageHeight",
            "imageWidth",
            "inferenceSteps",
            "isModelCustom",
            "isPhoenix",
            "isSDXL",
            "isSDXLLightning",
            "loraCount",
            "numImages",
            "photoRealMode",
            "photoRealStrength",
            "photoRealVersion",
            "promptMagic",
            "promptMagicStrength",
            "promptMagicVersion",
            "ultra",
        ]
        nullable_fields = [
            "controlnetsCost",
            "isModelCustom",
            "isPhoenix",
            "isSDXL",
            "isSDXLLightning",
            "loraCount",
            "photoRealMode",
            "photoRealStrength",
            "photoRealVersion",
            "promptMagic",
            "promptMagicStrength",
            "promptMagicVersion",
            "ultra",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PricingCalculatorPricingCalculatorRequestObjectTypedDict(TypedDict):
    r"""Parameters for LCM_GENERATION service"""

    height: NotRequired[Nullable[int]]
    r"""The output height of the image. Must be 512, 640 or 1024."""
    instant_refine: NotRequired[Nullable[bool]]
    r"""Enable for instant upscale"""
    refine: NotRequired[Nullable[bool]]
    r"""Enable for normal alchemy upscale"""
    width: NotRequired[Nullable[int]]
    r"""The output width of the image. Must be 512, 640 or 1024."""


class PricingCalculatorPricingCalculatorRequestObject(BaseModel):
    r"""Parameters for LCM_GENERATION service"""

    height: OptionalNullable[int] = UNSET
    r"""The output height of the image. Must be 512, 640 or 1024."""

    instant_refine: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="instantRefine")
    ] = UNSET
    r"""Enable for instant upscale"""

    refine: OptionalNullable[bool] = UNSET
    r"""Enable for normal alchemy upscale"""

    width: OptionalNullable[int] = UNSET
    r"""The output width of the image. Must be 512, 640 or 1024."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["height", "instantRefine", "refine", "width"]
        nullable_fields = ["height", "instantRefine", "refine", "width"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PricingCalculatorPricingCalculatorRequestRequestBodyObjectTypedDict(TypedDict):
    r"""Parameters for MODEL_TRAINING service"""

    resolution: NotRequired[int]
    r"""The resolution for training. Must be 512 or 768."""


class PricingCalculatorPricingCalculatorRequestRequestBodyObject(BaseModel):
    r"""Parameters for MODEL_TRAINING service"""

    resolution: Optional[int] = None
    r"""The resolution for training. Must be 512 or 768."""


class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObjectTypedDict(
    TypedDict
):
    r"""Parameters for MOTION_GENERATION service"""

    duration_seconds: NotRequired[int]
    r"""The total duration of the motion generation in seconds."""


class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObject(
    BaseModel
):
    r"""Parameters for MOTION_GENERATION service"""

    duration_seconds: Annotated[
        Optional[int], pydantic.Field(alias="durationSeconds")
    ] = None
    r"""The total duration of the motion generation in seconds."""


class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObjectTypedDict(
    TypedDict
):
    r"""Parameters for TEXTURE_GENERATION service"""

    preview: NotRequired[bool]


class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObject(
    BaseModel
):
    r"""Parameters for TEXTURE_GENERATION service"""

    preview: Optional[bool] = None


class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObjectTypedDict(
    TypedDict
):
    r"""Parameters for UNIVERSAL_UPSCALER service"""

    megapixel: NotRequired[int]
    r"""The maximum upscaled image size is 20 megapixels."""


class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObject(
    BaseModel
):
    r"""Parameters for UNIVERSAL_UPSCALER service"""

    megapixel: Optional[int] = None
    r"""The maximum upscaled image size is 20 megapixels."""


class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObjectTypedDict(
    TypedDict
):
    r"""Parameters for UNIVERSAL_UPSCALER_ULTRA service"""

    input_height: NotRequired[int]
    r"""The input height of the image."""
    input_width: NotRequired[int]
    r"""The input width of the image."""
    upscale_multiplier: NotRequired[float]
    r"""The upscale multiplier of the universal upscaler. Must be between 1.00 and 2.00."""


class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObject(
    BaseModel
):
    r"""Parameters for UNIVERSAL_UPSCALER_ULTRA service"""

    input_height: Annotated[Optional[int], pydantic.Field(alias="inputHeight")] = None
    r"""The input height of the image."""

    input_width: Annotated[Optional[int], pydantic.Field(alias="inputWidth")] = None
    r"""The input width of the image."""

    upscale_multiplier: Annotated[
        Optional[float], pydantic.Field(alias="upscaleMultiplier")
    ] = 1.5
    r"""The upscale multiplier of the universal upscaler. Must be between 1.00 and 2.00."""


class ObjectTypedDict(TypedDict):
    r"""Parameters for the service"""

    fantasy_avatar_generation: NotRequired[Nullable[PricingCalculatorObjectTypedDict]]
    r"""Parameters for FANTASY_AVATAR_GENERATION service"""
    image_generation: NotRequired[
        Nullable[PricingCalculatorPricingCalculatorObjectTypedDict]
    ]
    r"""Parameters for IMAGE_GENERATION service"""
    lcm_generation: NotRequired[
        Nullable[PricingCalculatorPricingCalculatorRequestObjectTypedDict]
    ]
    r"""Parameters for LCM_GENERATION service"""
    model_training: NotRequired[
        Nullable[PricingCalculatorPricingCalculatorRequestRequestBodyObjectTypedDict]
    ]
    r"""Parameters for MODEL_TRAINING service"""
    motion_generation: NotRequired[
        Nullable[
            PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObjectTypedDict
        ]
    ]
    r"""Parameters for MOTION_GENERATION service"""
    texture_generation: NotRequired[
        Nullable[
            PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObjectTypedDict
        ]
    ]
    r"""Parameters for TEXTURE_GENERATION service"""
    universal_upscaler: NotRequired[
        Nullable[
            PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObjectTypedDict
        ]
    ]
    r"""Parameters for UNIVERSAL_UPSCALER service"""
    universal_upscaler_ultra: NotRequired[
        Nullable[
            PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObjectTypedDict
        ]
    ]
    r"""Parameters for UNIVERSAL_UPSCALER_ULTRA service"""


class Object(BaseModel):
    r"""Parameters for the service"""

    fantasy_avatar_generation: Annotated[
        OptionalNullable[PricingCalculatorObject],
        pydantic.Field(alias="FANTASY_AVATAR_GENERATION"),
    ] = UNSET
    r"""Parameters for FANTASY_AVATAR_GENERATION service"""

    image_generation: Annotated[
        OptionalNullable[PricingCalculatorPricingCalculatorObject],
        pydantic.Field(alias="IMAGE_GENERATION"),
    ] = UNSET
    r"""Parameters for IMAGE_GENERATION service"""

    lcm_generation: Annotated[
        OptionalNullable[PricingCalculatorPricingCalculatorRequestObject],
        pydantic.Field(alias="LCM_GENERATION"),
    ] = UNSET
    r"""Parameters for LCM_GENERATION service"""

    model_training: Annotated[
        OptionalNullable[PricingCalculatorPricingCalculatorRequestRequestBodyObject],
        pydantic.Field(alias="MODEL_TRAINING"),
    ] = UNSET
    r"""Parameters for MODEL_TRAINING service"""

    motion_generation: Annotated[
        OptionalNullable[
            PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObject
        ],
        pydantic.Field(alias="MOTION_GENERATION"),
    ] = UNSET
    r"""Parameters for MOTION_GENERATION service"""

    texture_generation: Annotated[
        OptionalNullable[
            PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObject
        ],
        pydantic.Field(alias="TEXTURE_GENERATION"),
    ] = UNSET
    r"""Parameters for TEXTURE_GENERATION service"""

    universal_upscaler: Annotated[
        OptionalNullable[
            PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObject
        ],
        pydantic.Field(alias="UNIVERSAL_UPSCALER"),
    ] = UNSET
    r"""Parameters for UNIVERSAL_UPSCALER service"""

    universal_upscaler_ultra: Annotated[
        OptionalNullable[
            PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObject
        ],
        pydantic.Field(alias="UNIVERSAL_UPSCALER_ULTRA"),
    ] = UNSET
    r"""Parameters for UNIVERSAL_UPSCALER_ULTRA service"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "FANTASY_AVATAR_GENERATION",
            "IMAGE_GENERATION",
            "LCM_GENERATION",
            "MODEL_TRAINING",
            "MOTION_GENERATION",
            "TEXTURE_GENERATION",
            "UNIVERSAL_UPSCALER",
            "UNIVERSAL_UPSCALER_ULTRA",
        ]
        nullable_fields = [
            "FANTASY_AVATAR_GENERATION",
            "IMAGE_GENERATION",
            "LCM_GENERATION",
            "MODEL_TRAINING",
            "MOTION_GENERATION",
            "TEXTURE_GENERATION",
            "UNIVERSAL_UPSCALER",
            "UNIVERSAL_UPSCALER_ULTRA",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PricingCalculatorRequestBodyTypedDict(TypedDict):
    service: NotRequired[shared_pricingcalculatorservices.PricingCalculatorServices]
    r"""The services to be chosen for calculating the API credit cost."""
    service_params: NotRequired[ObjectTypedDict]
    r"""Parameters for the service"""


class PricingCalculatorRequestBody(BaseModel):
    service: Optional[shared_pricingcalculatorservices.PricingCalculatorServices] = None
    r"""The services to be chosen for calculating the API credit cost."""

    service_params: Annotated[
        Optional[Object], pydantic.Field(alias="serviceParams")
    ] = None
    r"""Parameters for the service"""


class CalculateProductionAPIServiceCostTypedDict(TypedDict):
    cost: NotRequired[int]
    r"""API service cost to generate the image."""


class CalculateProductionAPIServiceCost(BaseModel):
    cost: Optional[int] = None
    r"""API service cost to generate the image."""


class PricingCalculatorResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /pricing-calculator"""

    calculate_production_api_service_cost: NotRequired[
        Nullable[CalculateProductionAPIServiceCostTypedDict]
    ]


class PricingCalculatorResponseBody(BaseModel):
    r"""Responses for POST /pricing-calculator"""

    calculate_production_api_service_cost: Annotated[
        OptionalNullable[CalculateProductionAPIServiceCost],
        pydantic.Field(alias="calculateProductionApiServiceCost"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["calculateProductionApiServiceCost"]
        nullable_fields = ["calculateProductionApiServiceCost"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PricingCalculatorResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[PricingCalculatorResponseBodyTypedDict]
    r"""Responses for POST /pricing-calculator"""


class PricingCalculatorResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[PricingCalculatorResponseBody] = None
    r"""Responses for POST /pricing-calculator"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ModelAssetTextureTypes(str, Enum):
    r"""When training model assets these are the texture types available to use."""

    ALBEDO = "ALBEDO"
    NORMAL = "NORMAL"
    ROUGHNESS = "ROUGHNESS"
    DISPLACEMENT = "DISPLACEMENT"
    HDRP_MASK = "HDRP_MASK"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.models.shared import (
    lcm_generation_style as shared_lcm_generation_style,
)
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PerformInpaintingLCMRequestBodyTypedDict(TypedDict):
    r"""Query parameters can also be provided in the request body as a JSON object"""

    image_data_url: str
    r"""Image data used to generate image. In base64 format. Prefix: `data:image/jpeg;base64,`"""
    mask_data_url: str
    r"""Image data of the mask layer used for inpainting. In base64 format. Prefix: `data:image/jpeg;base64,`. Mask should be white on black where generation is applied to the white area."""
    prompt: str
    r"""The prompt used to generate images"""
    guidance: NotRequired[Nullable[float]]
    r"""How strongly the generation should reflect the prompt. Must be a float between 0.5 and 20."""
    height: NotRequired[Nullable[int]]
    r"""The output width of the image. Must be 512, 640 or 1024."""
    request_timestamp: NotRequired[str]
    seed: NotRequired[Nullable[int]]
    steps: NotRequired[Nullable[int]]
    r"""The number of steps to use for the generation. Must be between 4 and 16."""
    strength: NotRequired[Nullable[float]]
    r"""Creativity strength of generation. Higher strength will deviate more from the original image supplied in imageDataUrl. Must be a float between 0.1 and 1."""
    style: NotRequired[Nullable[shared_lcm_generation_style.LcmGenerationStyle]]
    r"""The style to generate LCM images with."""
    width: NotRequired[Nullable[int]]
    r"""The output width of the image. Must be 512, 640 or 1024."""


class PerformInpaintingLCMRequestBody(BaseModel):
    r"""Query parameters can also be provided in the request body as a JSON object"""

    image_data_url: Annotated[str, pydantic.Field(alias="imageDataUrl")]
    r"""Image data used to generate image. In base64 format. Prefix: `data:image/jpeg;base64,`"""

    mask_data_url: Annotated[str, pydantic.Field(alias="maskDataUrl")]
    r"""Image data of the mask layer used for inpainting. In base64 format. Prefix: `data:image/jpeg;base64,`. Mask should be white on black where generation is applied to the white area."""

    prompt: str
    r"""The prompt used to generate images"""

    guidance: OptionalNullable[float] = UNSET
    r"""How strongly the generation should reflect the prompt. Must be a float between 0.5 and 20."""

    height: OptionalNullable[int] = 512
    r"""The output width of the image. Must be 512, 640 or 1024."""

    request_timestamp: Annotated[
        Optional[str], pydantic.Field(alias="requestTimestamp")
    ] = None

    seed: OptionalNullable[int] = UNSET

    steps: OptionalNullable[int] = UNSET
    r"""The number of steps to use for the generation. Must be between 4 and 16."""

    strength: OptionalNullable[float] = UNSET
    r"""Creativity strength of generation. Higher strength will deviate more from the original image supplied in imageDataUrl. Must be a float between 0.1 and 1."""

    style: OptionalNullable[shared_lcm_generation_style.LcmGenerationStyle] = UNSET
    r"""The style to generate LCM images with."""

    width: OptionalNullable[int] = 512
    r"""The output width of the image. Must be 512, 640 or 1024."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "guidance",
            "height",
            "requestTimestamp",
            "seed",
            "steps",
            "strength",
            "style",
            "width",
        ]
        nullable_fields = [
            "guidance",
            "height",
            "seed",
            "steps",
            "strength",
            "style",
            "width",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PerformInpaintingLCMLCMGenerationOutputTypedDict(TypedDict):
    api_credit_cost: NotRequired[Nullable[int]]
    r"""API credits cost, available for Production API users."""
    image_data_url: NotRequired[List[str]]
    request_timestamp: NotRequired[str]


class PerformInpaintingLCMLCMGenerationOutput(BaseModel):
    api_credit_cost: Annotated[
        OptionalNullable[int], pydantic.Field(alias="apiCreditCost")
    ] = UNSET
    r"""API credits cost, available for Production API users."""

    image_data_url: Annotated[
        Optional[List[str]], pydantic.Field(alias="imageDataUrl")
    ] = None

    request_timestamp: Annotated[
        Optional[str], pydantic.Field(alias="requestTimestamp")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["apiCreditCost", "imageDataUrl", "requestTimestamp"]
        nullable_fields = ["apiCreditCost"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PerformInpaintingLCMResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /lcm-inpainting"""

    lcm_generation_job: NotRequired[
        Nullable[PerformInpaintingLCMLCMGenerationOutputTypedDict]
    ]


class PerformInpaintingLCMResponseBody(BaseModel):
    r"""Responses for POST /lcm-inpainting"""

    lcm_generation_job: Annotated[
        OptionalNullable[PerformInpaintingLCMLCMGenerationOutput],
        pydantic.Field(alias="lcmGenerationJob"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["lcmGenerationJob"]
        nullable_fields = ["lcmGenerationJob"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PerformInpaintingLCMResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[PerformInpaintingLCMResponseBodyTypedDict]
    r"""Responses for POST /lcm-inpainting"""


class PerformInpaintingLCMResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[PerformInpaintingLCMResponseBody] = None
    r"""Responses for POST /lcm-inpainting"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UsersTypedDict(TypedDict):
    r"""columns and relationships of \"users\" """

    id: NotRequired[Nullable[str]]
    username: NotRequired[Nullable[str]]
    r"""Username of the user."""


class Users(BaseModel):
    r"""columns and relationships of \"users\" """

    id: OptionalNullable[str] = UNSET

    username: OptionalNullable[str] = UNSET
    r"""Username of the user."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "username"]
        nullable_fields = ["id", "username"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UserDetailsTypedDict(TypedDict):
    r"""columns and relationships of \"user_details\" """

    api_concurrency_slots: NotRequired[int]
    r"""API Concurrency Slots."""
    api_paid_tokens: NotRequired[Nullable[int]]
    r"""Current balance of API paid tokens the user has."""
    api_plan_token_renewal_date: NotRequired[Nullable[str]]
    r"""API Plan Token Renewal Date."""
    api_subscription_tokens: NotRequired[int]
    r"""Current balance of Enterprise API subscriptions tokens the user has."""
    paid_tokens: NotRequired[Nullable[int]]
    r"""Current balance of paid tokens the user has."""
    subscription_gpt_tokens: NotRequired[int]
    r"""Current balance of user plan GPT tokens the user has."""
    subscription_model_tokens: NotRequired[int]
    r"""Current balance of model training tokens the user has."""
    subscription_tokens: NotRequired[int]
    r"""Current balance of user plan subscription tokens the user has."""
    token_renewal_date: NotRequired[Nullable[str]]
    r"""User Plan Token Renewal Date."""
    user: NotRequired[Nullable[UsersTypedDict]]
    r"""columns and relationships of \"users\" """


class UserDetails(BaseModel):
    r"""columns and relationships of \"user_details\" """

    api_concurrency_slots: Annotated[
        Optional[int], pydantic.Field(alias="apiConcurrencySlots")
    ] = None
    r"""API Concurrency Slots."""

    api_paid_tokens: Annotated[
        OptionalNullable[int], pydantic.Field(alias="apiPaidTokens")
    ] = UNSET
    r"""Current balance of API paid tokens the user has."""

    api_plan_token_renewal_date: Annotated[
        OptionalNullable[str], pydantic.Field(alias="apiPlanTokenRenewalDate")
    ] = UNSET
    r"""API Plan Token Renewal Date."""

    api_subscription_tokens: Annotated[
        Optional[int], pydantic.Field(alias="apiSubscriptionTokens")
    ] = None
    r"""Current balance of Enterprise API subscriptions tokens the user has."""

    paid_tokens: Annotated[
        OptionalNullable[int], pydantic.Field(alias="paidTokens")
    ] = UNSET
    r"""Current balance of paid tokens the user has."""

    subscription_gpt_tokens: Annotated[
        Optional[int], pydantic.Field(alias="subscriptionGptTokens")
    ] = None
    r"""Current balance of user plan GPT tokens the user has."""

    subscription_model_tokens: Annotated[
        Optional[int], pydantic.Field(alias="subscriptionModelTokens")
    ] = None
    r"""Current balance of model training tokens the user has."""

    subscription_tokens: Annotated[
        Optional[int], pydantic.Field(alias="subscriptionTokens")
    ] = None
    r"""Current balance of user plan subscription tokens the user has."""

    token_renewal_date: Annotated[
        OptionalNullable[str], pydantic.Field(alias="tokenRenewalDate")
    ] = UNSET
    r"""User Plan Token Renewal Date."""

    user: OptionalNullable[Users] = UNSET
    r"""columns and relationships of \"users\" """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "apiConcurrencySlots",
            "apiPaidTokens",
            "apiPlanTokenRenewalDate",
            "apiSubscriptionTokens",
            "paidTokens",
            "subscriptionGptTokens",
            "subscriptionModelTokens",
            "subscriptionTokens",
            "tokenRenewalDate",
            "user",
        ]
        nullable_fields = [
            "apiPaidTokens",
            "apiPlanTokenRenewalDate",
            "paidTokens",
            "tokenRenewalDate",
            "user",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetUserSelfResponseBodyTypedDict(TypedDict):
    r"""Responses for GET /me"""

    user_details: NotRequired[List[UserDetailsTypedDict]]


class GetUserSelfResponseBody(BaseModel):
    r"""Responses for GET /me"""

    user_details: Optional[List[UserDetails]] = None


class GetUserSelfResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[GetUserSelfResponseBodyTypedDict]
    r"""Responses for GET /me"""


class GetUserSelfResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[GetUserSelfResponseBody] = None
    r"""Responses for GET /me"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class VariationType(str, Enum):
    r"""The type of variation."""

    OUTPAINT = "OUTPAINT"
    INPAINT = "INPAINT"
    UPSCALE = "UPSCALE"
    UNZOOM = "UNZOOM"
    NOBG = "NOBG"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from leonardo_ai_sdk.utils import FieldMetadata, PathParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteGenerationByIDRequestTypedDict(TypedDict):
    id: str
    r"""The ID of the generation to delete."""


class DeleteGenerationByIDRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the generation to delete."""


class GenerationsTypedDict(TypedDict):
    r"""columns and relationships of \"generations\" """

    id: NotRequired[Nullable[str]]


class Generations(BaseModel):
    r"""columns and relationships of \"generations\" """

    id: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id"]
        nullable_fields = ["id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DeleteGenerationByIDResponseBodyTypedDict(TypedDict):
    r"""Responses for DELETE /generations/{id}"""

    delete_generations_by_pk: NotRequired[Nullable[GenerationsTypedDict]]
    r"""columns and relationships of \"generations\" """


class DeleteGenerationByIDResponseBody(BaseModel):
    r"""Responses for DELETE /generations/{id}"""

    delete_generations_by_pk: OptionalNullable[Generations] = UNSET
    r"""columns and relationships of \"generations\" """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["delete_generations_by_pk"]
        nullable_fields = ["delete_generations_by_pk"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DeleteGenerationByIDResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[DeleteGenerationByIDResponseBodyTypedDict]
    r"""Responses for DELETE /generations/{id}"""


class DeleteGenerationByIDResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[DeleteGenerationByIDResponseBody] = None
    r"""Responses for DELETE /generations/{id}"""
